﻿/*
 * WCF Self hosting sample from www.WayneCliffordBarker.co.za
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.ServiceModel;
using System.ServiceModel.Security;
using System.IdentityModel.Tokens;
using System.Threading;
using System.Security.Claims;
using ActiveSTSProxy;

namespace WSTrustServiceTest
{
    class Program
    {
        static void Main(string[] args)
        {
            string invalidUserName = "Jean-Luc";
            string validUserName = "Jean-Luc Picard";
            string password = "Picard-Delta-5";

            Console.ForegroundColor = ConsoleColor.Yellow;
            Console.WriteLine("Valid user login test".ToUpper());
            Console.WriteLine("*********************************************************************");
            Console.WriteLine("");
            Console.ForegroundColor = ConsoleColor.White;
            SessionSecurityToken token = LogUserIn(validUserName, password);

            if (token != null)
            {
                LogUserOut(ref token);
            }

            Console.ForegroundColor = ConsoleColor.Yellow;
            Console.WriteLine("Press key to continue");
            Console.ForegroundColor = ConsoleColor.White;
            Console.ReadKey();
            Console.Clear();
            Console.ForegroundColor = ConsoleColor.Yellow;
            Console.WriteLine("Invalid user login test".ToUpper());
            Console.WriteLine("*********************************************************************");
            Console.ForegroundColor = ConsoleColor.White;
            Console.WriteLine("");
            token = LogUserIn(invalidUserName, password);

            Console.ForegroundColor = ConsoleColor.Yellow;
            Console.WriteLine("Press key to exit");
            Console.ForegroundColor = ConsoleColor.White;
            Console.ReadKey();
        }

        private static SessionSecurityToken LogUserIn(string userName, string password)
        {
            try
           {
                Console.WriteLine("Identity of user before login");
                Console.WriteLine("---------------------------------------------------------------------");
                ClaimsIdentity identity = (Thread.CurrentPrincipal.Identity as ClaimsIdentity);
                foreach (Claim claim in identity.Claims)
                {
                    Console.WriteLine(claim.ToString());
                }
                Console.WriteLine("---------------------------------------------------------------------");
                Console.WriteLine("");
                Console.WriteLine("User to login");
                Console.WriteLine(String.Format("Username : {0}", userName));
                Console.WriteLine(String.Format("Password : {0}", password));
                Console.WriteLine("");
                Console.ForegroundColor = ConsoleColor.Yellow;
                Console.WriteLine("Press any key to run the test.");
                Console.ForegroundColor = ConsoleColor.White;
                Console.ReadKey();
                Console.WriteLine("");
                Console.WriteLine("Attempting login...");

                SessionSecurityToken token = null;

                if (Proxy.SignIn(userName, password, out token))
                {
                    Console.ForegroundColor = ConsoleColor.Green;
                    Console.WriteLine("Login Successfull.");
                    Console.ForegroundColor = ConsoleColor.White;
                }
                else
                {
                    Console.ForegroundColor = ConsoleColor.Red;
                    Console.WriteLine("Login Failed.");
                    Console.ForegroundColor = ConsoleColor.White;
                }

                Console.WriteLine("");
                Console.WriteLine("Identity of user after login");
                Console.WriteLine("---------------------------------------------------------------------");
                identity = (Thread.CurrentPrincipal.Identity as ClaimsIdentity);
                foreach (Claim claim in identity.Claims)
                {
                    Console.WriteLine(claim.ToString());
                }
                Console.WriteLine("---------------------------------------------------------------------");
                Console.WriteLine("");
                return token;
            }
            catch (Exception e)
            {
                Console.ForegroundColor = ConsoleColor.Red;
                Console.WriteLine(String.Format("Error {0}", e.Message));
                Console.ForegroundColor = ConsoleColor.White;
            }
            return null;
        }

        private static void LogUserOut(ref SessionSecurityToken token)
        {
            Console.ForegroundColor = ConsoleColor.Yellow;
            Console.WriteLine("Press key to log out.");
            Console.ForegroundColor = ConsoleColor.White;
            Console.ReadKey();
            Console.ForegroundColor = ConsoleColor.Yellow;
            Console.WriteLine("Logout test".ToUpper());
            Console.WriteLine("*********************************************************************");
            Console.ForegroundColor = ConsoleColor.White;
            ActiveSTSProxy.Proxy.SignOut(ref token);
            Console.WriteLine("");
            Console.WriteLine("Identity of user after log out");
            Console.WriteLine("---------------------------------------------------------------------");
            ClaimsIdentity identity = (Thread.CurrentPrincipal.Identity as ClaimsIdentity);
            foreach (Claim claim in identity.Claims)
            {
                Console.WriteLine(claim.ToString());
            }
            Console.WriteLine("---------------------------------------------------------------------");
            Console.WriteLine("");
        }
    }
}
